@@ -35,14 +35,14 @@ class Client : public PulseObject
     Q_OBJECT
     Q_PROPERTY(QString name READ name NOTIFY nameChanged)
 public:
-    Client(QObject *parent);
-    virtual ~Client();
+    explicit Client(QObject *parent);
+    ~Client() override;
 
     void update(const pa_client_info *info);
 
     QString name() const;
 
-signals:
+Q_SIGNALS:
     void nameChanged();
 
 private:
